<?php

namespace Drupal\webform_calculation_fields\Plugin\WebformElement;

use Drupal\Core\Form\FormStateInterface;
use Drupal\webform\Plugin\WebformElement\TextField;

/**
 * Provides a Webform calculation element.
 *
 * @WebformElement(
 *   id = "form_calculation_markup",
 *   label = @Translation("Calculation Markup"),
 *   description = @Translation("Provided an advance markup that can evaluate expression inside {{ }} tags."),
 *   category = @Translation("Calculation elements"),
 * )
 */
class WebformCalculationMarkup extends TextField {

  /**
   * {@inheritDoc}
   */
  public function defineDefaultProperties() {
    $default = parent::defineDefaultProperties();
    $custom = [
      'evaluation_decimals' => NULL,
      'evaluation_fields' => '',
      'placeholder' => '',
    ];
    return array_merge(
      $default,
      $custom
    );
  }

  /**
   * {@inheritDoc}
   */
  public function form(array $form, FormStateInterface $form_state) {
    $form = parent::form($form, $form_state);
    unset($form["summary_attributes"]);
    unset($form["validation"]);
    unset($form["element_description"]);
    unset($form["form"]);

    $form['element']['evaluation_fields'] = [
      '#type' => 'webform_html_editor',
      '#title' => $this->t('Math Expression and the Html markup'),
      '#description' => $this->t('e.g.: <h3>:webform_element_key_1 + :webform_element_key_2 - (:webform_element_key_1 * :webform_element_key_3)</h3>'),
    ];

    $form['element']['evaluation_decimals'] = [
      '#type' => 'number',
      '#min' => 0,
      '#title' => $this->t('Decimals'),
      '#description' => $this->t('Specify the number of decimal places for the calculation result'),
      '#weight' => 1,
    ];

    $form['element']['placeholder'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Placeholder'),
      '#description' => $this->t('The text to be displayed until all inputs required by this field are populated. If not provided, the markup element will only be displayed once the calculation is complete.'),
      '#weight' => 2,
    ];
    return $form;
  }

}
