<?php

namespace Drupal\webform_calculation_fields\Plugin\WebformElement;

use Drupal\Core\Form\FormStateInterface;
use Drupal\webform\Plugin\WebformElement\Number;

/**
 * Provides a Webform Math element.
 *
 * @WebformElement(
 *   id = "form_calculation_element",
 *   label = @Translation("Calculation Field"),
 *   description = @Translation("Provides a math element capable to evaluate math expressions."),
 *   category = @Translation("Calculation elements"),
 * )
 */
class WebformCalculationNumber extends Number {

  /**
   * {@inheritDoc}
   */
  public function defineDefaultProperties() {
    return parent::defineDefaultProperties() + [
      'evaluation_fields' => '',
      'evaluation_decimals' => NULL,
    ];
  }

  /**
   * {@inheritDoc}
   */
  public function form(array $form, FormStateInterface $form_state) {
    $form = parent::form($form, $form_state);

    $form['element']['evaluation_decimals'] = [
      '#type' => 'number',
      '#min' => 0,
      '#title' => $this->t('Round result'),
      '#description' => $this->t('Specify the number of decimal places for the calculation result'),
      '#weight' => 1,
    ];

    $form['element']['evaluation_fields'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Math Expression'),
      '#description' => $this->t('e.g.: :webform_element_key_1 + :webform_element_key_2 - (:webform_element_key_1 * :webform_element_key_3)'),
      '#weight' => 2,
    ];
    return $form;
  }

}
